@@ -43,6 +43,7 @@ extern flid_t osi_flid;
 #define vfs_data vfs_bh.bh_first->bd_pdata
 #endif /* AFS_SGI64_ENV */
 
+#define ifnet_flags(x) (x?(x)->if_flags:0)
 
 /*
  * Global lock, semaphore, mutex and state vector support.
@@ -172,11 +173,6 @@ extern long afs_global_owner;
     (AFS_ASSERT_GLOCK(), afs_global_owner = 0, mutex_exit(&afs_global_lock))
 #define ISAFS_GLOCK() (osi_ThreadUnique() == afs_global_owner)
 #endif /* AFS_SGI64_ENV */
-
-#define AFS_RXGLOCK()
-#define AFS_RXGUNLOCK()
-#define ISAFS_RXGLOCK() 1
-
 #else /* MP */
 #define AFS_GLOCK()
 #define AFS_GUNLOCK()
