@@ -11,7 +11,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_file.c,v 1.19.2.4 2005/03/11 04:37:17 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/LINUX/osi_file.c,v 1.19.2.9 2006/02/15 21:03:38 shadow Exp $");
 
 #ifdef AFS_LINUX24_ENV
 #include "h/module.h" /* early to avoid printf->printk mapping */
@@ -26,8 +26,58 @@ int afs_osicred_initialized = 0;
 struct AFS_UCRED afs_osi_cred;
 afs_lock_t afs_xosi;		/* lock is for tvattr */
 extern struct osi_dev cacheDev;
+#if defined(AFS_LINUX24_ENV)
+extern struct vfsmount *afs_cacheMnt;
+#endif
 extern struct super_block *afs_cacheSBp;
 
+#if defined(AFS_LINUX26_ENV) 
+void *
+osi_UFSOpen(afs_int32 ainode)
+{
+    register struct osi_file *afile = NULL;
+    extern int cacheDiskType;
+    struct inode *tip = NULL;
+    struct dentry *dp = NULL;
+    struct file *filp = NULL;
+    AFS_STATCNT(osi_UFSOpen);
+    if (cacheDiskType != AFS_FCACHE_TYPE_UFS) {
+	osi_Panic("UFSOpen called for non-UFS cache\n");
+    }
+    if (!afs_osicred_initialized) {
+	/* valid for alpha_osf, SunOS, Ultrix */
+	memset((char *)&afs_osi_cred, 0, sizeof(struct AFS_UCRED));
+	crhold(&afs_osi_cred);	/* don't let it evaporate, since it is static */
+	afs_osicred_initialized = 1;
+    }
+    afile = (struct osi_file *)osi_AllocLargeSpace(sizeof(struct osi_file));
+    AFS_GUNLOCK();
+    if (!afile) {
+	osi_Panic("osi_UFSOpen: Failed to allocate %d bytes for osi_file.\n",
+		  sizeof(struct osi_file));
+    }
+    memset(afile, 0, sizeof(struct osi_file));
+    tip = iget(afs_cacheSBp, (u_long) ainode);
+    if (!tip)
+	osi_Panic("Can't get inode %d\n", ainode);
+    tip->i_flags |= MS_NOATIME;	/* Disable updating access times. */
+
+    dp = d_alloc_anon(tip);
+    if (!dp) 
+           osi_Panic("Can't get dentry for inode %d\n", ainode);          
+
+    filp = dentry_open(dp, mntget(afs_cacheMnt), O_RDWR);
+    if (IS_ERR(filp))
+	osi_Panic("Can't open inode %d\n", ainode);
+    afile->filp = filp;
+    afile->size = FILE_INODE(filp)->i_size;
+    AFS_GLOCK();
+    afile->offset = 0;
+    afile->proc = (int (*)())0;
+    afile->inum = ainode;	/* for hint validity checking */
+    return (void *)afile;
+}
+#else
 void *
 osi_UFSOpen(afs_int32 ainode)
 {
@@ -61,10 +111,8 @@ osi_UFSOpen(afs_int32 ainode)
     FILE_INODE(filp) = tip;
     tip->i_flags |= MS_NOATIME;	/* Disable updating access times. */
     filp->f_flags = O_RDWR;
-#if defined(AFS_LINUX26_ENV)
-    filp->f_mapping = tip->i_mapping;
-#endif
 #if defined(AFS_LINUX24_ENV)
+    filp->f_mode = FMODE_READ|FMODE_WRITE;
     filp->f_op = fops_get(tip->i_fop);
 #else
     filp->f_op = tip->i_op->default_file_ops;
@@ -80,6 +128,7 @@ osi_UFSOpen(afs_int32 ainode)
     afile->inum = ainode;	/* for hint validity checking */
     return (void *)afile;
 }
+#endif
 
 int
 afs_osi_Stat(register struct osi_file *afile, register struct osi_stat *astat)
@@ -87,20 +136,35 @@ afs_osi_Stat(register struct osi_file *afile, register struct osi_stat *astat)
     register afs_int32 code;
     AFS_STATCNT(osi_Stat);
     MObtainWriteLock(&afs_xosi, 320);
-    astat->size = FILE_INODE(&afile->file)->i_size;
-    astat->blksize = FILE_INODE(&afile->file)->i_blksize;
+    astat->size = OSIFILE_INODE(afile)->i_size;
+    astat->blksize = OSIFILE_INODE(afile)->i_blksize;
 #if defined(AFS_LINUX26_ENV)
-    astat->mtime = FILE_INODE(&afile->file)->i_mtime.tv_sec;
-    astat->atime = FILE_INODE(&afile->file)->i_atime.tv_sec;
+    astat->mtime = OSIFILE_INODE(afile)->i_mtime.tv_sec;
+    astat->atime = OSIFILE_INODE(afile)->i_atime.tv_sec;
 #else
-    astat->mtime = FILE_INODE(&afile->file)->i_mtime;
-    astat->atime = FILE_INODE(&afile->file)->i_atime;
+    astat->mtime = OSIFILE_INODE(afile)->i_mtime;
+    astat->atime = OSIFILE_INODE(afile)->i_atime;
 #endif
     code = 0;
     MReleaseWriteLock(&afs_xosi);
     return code;
 }
 
+#ifdef AFS_LINUX26_ENV
+int
+osi_UFSClose(register struct osi_file *afile)
+{
+    AFS_STATCNT(osi_Close);
+    if (afile) {
+	if (OSIFILE_INODE(afile)) {
+	    filp_close(afile->filp, NULL);
+	}
+    }
+
+    osi_FreeLargeSpace(afile);
+    return 0;
+}
+#else
 int
 osi_UFSClose(register struct osi_file *afile)
 {
@@ -117,6 +181,7 @@ osi_UFSClose(register struct osi_file *afile)
     osi_FreeLargeSpace(afile);
     return 0;
 }
+#endif
 
 int
 osi_UFSTruncate(register struct osi_file *afile, afs_int32 asize)
@@ -124,7 +189,7 @@ osi_UFSTruncate(register struct osi_file *afile, afs_int32 asize)
     register afs_int32 code;
     struct osi_stat tstat;
     struct iattr newattrs;
-    struct inode *inode = FILE_INODE(&afile->file);
+    struct inode *inode = OSIFILE_INODE(afile);
     AFS_STATCNT(osi_Truncate);
 
     /* This routine only shrinks files, and most systems
@@ -139,7 +204,11 @@ osi_UFSTruncate(register struct osi_file *afile, afs_int32 asize)
 #ifdef STRUCT_INODE_HAS_I_ALLOC_SEM
     down_write(&inode->i_alloc_sem);
 #endif
+#ifdef STRUCT_INODE_HAS_I_MUTEX
+    mutex_lock(&inode->i_mutex);
+#else
     down(&inode->i_sem);
+#endif
     newattrs.ia_size = asize;
     newattrs.ia_valid = ATTR_SIZE | ATTR_CTIME;
 #if defined(AFS_LINUX24_ENV)
@@ -169,7 +238,11 @@ osi_UFSTruncate(register struct osi_file *afile, afs_int32 asize)
     }
 #endif
     code = -code;
+#ifdef STRUCT_INODE_HAS_I_MUTEX
+    mutex_unlock(&inode->i_mutex);
+#else
     up(&inode->i_sem);
+#endif
 #ifdef STRUCT_INODE_HAS_I_ALLOC_SEM
     up_write(&inode->i_alloc_sem);
 #endif
@@ -184,14 +257,16 @@ int
 afs_osi_Read(register struct osi_file *afile, int offset, void *aptr,
 	     afs_int32 asize)
 {
-    size_t resid;
-    register afs_int32 code;
+    struct uio auio;
+    struct iovec iov;
+    afs_int32 code;
+
     AFS_STATCNT(osi_Read);
 
-    /**
-      * If the osi_file passed in is NULL, panic only if AFS is not shutting
-      * down. No point in crashing when we are already shutting down
-      */
+    /*
+     * If the osi_file passed in is NULL, panic only if AFS is not shutting
+     * down. No point in crashing when we are already shutting down
+     */
     if (!afile) {
 	if (!afs_shuttingdown)
 	    osi_Panic("osi_Read called with null param");
@@ -201,14 +276,15 @@ afs_osi_Read(register struct osi_file *afile, int offset, void *aptr,
 
     if (offset != -1)
 	afile->offset = offset;
+    setup_uio(&auio, &iov, aptr, afile->offset, asize, UIO_READ, AFS_UIOSYS);
     AFS_GUNLOCK();
-    code = osi_rdwr(UIO_READ, afile, (caddr_t) aptr, asize, &resid);
+    code = osi_rdwr(afile, &auio, UIO_READ);
     AFS_GLOCK();
     if (code == 0) {
-	code = asize - resid;
+	code = asize - auio.uio_resid;
 	afile->offset += code;
     } else {
-	afs_Trace2(afs_iclSetp, CM_TRACE_READFAILED, ICL_TYPE_INT32, resid,
+	afs_Trace2(afs_iclSetp, CM_TRACE_READFAILED, ICL_TYPE_INT32, auio.uio_resid,
 		   ICL_TYPE_INT32, code);
 	code = -1;
     }
@@ -220,22 +296,27 @@ int
 afs_osi_Write(register struct osi_file *afile, afs_int32 offset, void *aptr,
 	      afs_int32 asize)
 {
-    size_t resid;
-    register afs_int32 code;
+    struct uio auio;
+    struct iovec iov;
+    afs_int32 code;
+
     AFS_STATCNT(osi_Write);
+
     if (!afile) {
 	if (!afs_shuttingdown)
 	    osi_Panic("afs_osi_Write called with null param");
 	else
 	    return EIO;
     }
+
     if (offset != -1)
 	afile->offset = offset;
+    setup_uio(&auio, &iov, aptr, afile->offset, asize, UIO_WRITE, AFS_UIOSYS);
     AFS_GUNLOCK();
-    code = osi_rdwr(UIO_WRITE, afile, (caddr_t) aptr, asize, &resid);
+    code = osi_rdwr(afile, &auio, UIO_WRITE);
     AFS_GLOCK();
     if (code == 0) {
-	code = asize - resid;
+	code = asize - auio.uio_resid;
 	afile->offset += code;
     } else {
 	if (code == ENOSPC)
@@ -243,9 +324,10 @@ afs_osi_Write(register struct osi_file *afile, afs_int32 offset, void *aptr,
 		("\n\n\n*** Cache partition is FULL - Decrease cachesize!!! ***\n\n");
 	code = -1;
     }
-    if (afile->proc) {
-	(*afile->proc) (afile, code);
-    }
+
+    if (afile->proc)
+	(*afile->proc)(afile, code);
+
     return code;
 }
 
