@@ -22,7 +22,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_symlink.c,v 1.19.2.4 2005/01/31 03:49:15 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_symlink.c,v 1.19.2.5 2005/10/15 02:33:12 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -191,6 +191,12 @@ int afs_symlink
      * no one can get a pointer to the new cache entry until we release 
      * the xvcache lock. */
     tvc = afs_NewVCache(&newFid, hostp);
+    if (!tvc)
+    {
+	code = -2;
+	ReleaseWriteLock(&afs_xvcache);
+	goto done;
+    }
     ObtainWriteLock(&tvc->lock, 157);
     ObtainWriteLock(&afs_xcbhash, 500);
     tvc->states |= CStatd;	/* have valid info */
