@@ -23,7 +23,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_osi_pag.c,v 1.21.2.3 2005/01/31 04:19:20 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/afs_osi_pag.c,v 1.21.2.5 2005/10/05 05:58:27 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -141,39 +141,40 @@ getpag(void)
 
 static int afs_pag_sleepcnt = 0;
 
-static int 
-afs_pag_sleep(struct AFS_UCRED **acred) 
+static int
+afs_pag_sleep(struct AFS_UCRED **acred)
 {
-  int rv = 0;
-  if(!afs_suser(acred)) {
-    if(osi_Time() - pag_epoch < pagCounter) {
-      rv = 1;
-    }
-  }
+    int rv = 0;
 
-  return rv;
+    if (!afs_suser(acred)) {
+	if(osi_Time() - pag_epoch < pagCounter) {
+	    rv = 1;
+	}
+    }
+
+    return rv;
 }
 
-static int 
+static int
 afs_pag_wait(struct AFS_UCRED **acred)
 {
-  if(afs_pag_sleep(acred)) {
-    if(!afs_pag_sleepcnt) {
-      printf("%s() PAG throttling triggered, pid %d... sleeping.  sleepcnt %d\n",
-	     "afs_pag_wait", getpid(), afs_pag_sleepcnt);
-    }
-    
-    afs_pag_sleepcnt++;
-    
-    do {
-      /* XXX spins on EINTR */
-      afs_osi_Wait(1000, (struct afs_osi_WaitHandle *)0, 0);
-    } while(afs_pag_sleep(acred));
-    
-    afs_pag_sleepcnt--;
-  }
+    if (afs_pag_sleep(acred)) {
+	if (!afs_pag_sleepcnt) {
+	    printf("%s() PAG throttling triggered, pid %d... sleeping.  sleepcnt %d\n",
+		   "afs_pag_wait", osi_getpid(), afs_pag_sleepcnt);
+	}
 
-  return 0;
+	afs_pag_sleepcnt++;
+
+	do {
+	    /* XXX spins on EINTR */
+	    afs_osi_Wait(1000, (struct afs_osi_WaitHandle *)0, 0);
+	} while (afs_pag_sleep(acred));
+
+	afs_pag_sleepcnt--;
+    }
+
+    return 0;
 }
 
 int
@@ -240,6 +241,12 @@ afs_setpag(void)
 	code = AddPag(genpag(), &credp);
 	crfree(credp);
     }
+#elif defined(AFS_DARWIN80_ENV)
+    {
+	struct ucred *credp = kauth_cred_proc_ref(p);
+	code = AddPag(p, genpag(), &credp);
+	kauth_cred_rele(credp);
+    }
 #elif defined(AFS_DARWIN_ENV)
     {
 	struct ucred *credp = crdup(p->p_cred->pc_ucred);
