@@ -48,6 +48,7 @@
 #define SYS_NAME_ID_hp_ux11i             416
 #define SYS_NAME_ID_ia64_hpux1122	 417
 #define SYS_NAME_ID_ia64_hpux1123	 418
+#define SYS_NAME_ID_hp_ux1123		 419
 
 #define SYS_NAME_ID_mac2_51		 500
 #define SYS_NAME_ID_mac_aux10		 501
@@ -57,6 +58,10 @@
 #define SYS_NAME_ID_ppc_darwin_14        505
 #define SYS_NAME_ID_ppc_darwin_60        506
 #define SYS_NAME_ID_ppc_darwin_70        507
+#define SYS_NAME_ID_ppc_darwin_80        508
+#define SYS_NAME_ID_x86_darwin_80        509
+#define SYS_NAME_ID_ppc_darwin_90        510
+#define SYS_NAME_ID_x86_darwin_90        511
 
 #define SYS_NAME_ID_next_mach20		 601
 #define SYS_NAME_ID_next_mach30		 602
@@ -67,6 +72,7 @@
 #define SYS_NAME_ID_rs_aix51		 704
 #define SYS_NAME_ID_rs_aix43		 705
 #define SYS_NAME_ID_rs_aix52		 706
+#define SYS_NAME_ID_rs_aix53		 707
 
 #define SYS_NAME_ID_sun3_411		 906
 #define SYS_NAME_ID_sun3x_411		 912
@@ -148,10 +154,12 @@
 #define SYS_NAME_ID_sparc64_linux2	1800
 #define SYS_NAME_ID_sparc64_linux22	1801
 #define SYS_NAME_ID_sparc64_linux24	1802
+#define SYS_NAME_ID_sparc64_linux26	1803
 
 #define SYS_NAME_ID_s390_linux2         1900
 #define SYS_NAME_ID_s390_linux22        1901
 #define SYS_NAME_ID_s390_linux24        1902
+#define SYS_NAME_ID_s390_linux26        1907
 #define SYS_NAME_ID_s390x_linux2         1903
 #define SYS_NAME_ID_s390x_linux22        1904
 #define SYS_NAME_ID_s390x_linux24        1905
@@ -172,6 +180,7 @@
 #define SYS_NAME_ID_i386_fbsd_51        2106
 #define SYS_NAME_ID_i386_fbsd_52        2107
 #define SYS_NAME_ID_i386_fbsd_53        2108
+#define SYS_NAME_ID_i386_fbsd_60        2112
 
 #define SYS_NAME_ID_ia64_linux2		2200
 #define SYS_NAME_ID_ia64_linux22	2201
@@ -202,6 +211,7 @@
 #define SYS_NAME_ID_macppc_nbsd20	2524
 #define SYS_NAME_ID_i386_nbsd21		2525
 #define SYS_NAME_ID_i386_nbsd30		2526
+#define SYS_NAME_ID_amd64_nbsd20	2527
 
 #define SYS_NAME_ID_i386_obsd31		2600
 #define SYS_NAME_ID_i386_obsd32		2601
@@ -209,6 +219,8 @@
 #define SYS_NAME_ID_i386_obsd34		2603
 #define SYS_NAME_ID_i386_obsd35		2604
 #define SYS_NAME_ID_i386_obsd36		2605
+#define SYS_NAME_ID_i386_obsd37		2606
+#define SYS_NAME_ID_i386_obsd38		2607
 
 #define SYS_NAME_ID_amd64_linux2        2700
 #define SYS_NAME_ID_amd64_linux22       2701
@@ -227,9 +239,9 @@
 
 #define SYS_NAME_ID_amd64_fbsd_53        3008
 
-#define SYS_NAME_ID_amd64_w2k           3100
+#define SYS_NAME_ID_amd64_w2k           3400
 
-#define SYS_NAME_ID_i64_w2k             3200
+#define SYS_NAME_ID_i64_w2k             3500
 
 /*
  * Placeholder to keep system-wide standard flags since this file is included by all 
