@@ -20,7 +20,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/viced/viced.c,v 1.58.2.3 2005/02/24 15:23:41 shadow Exp $");
+    ("$Header: /cvs/openafs/src/viced/viced.c,v 1.58.2.11 2006/02/22 05:02:04 jaltman Exp $");
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -28,8 +28,8 @@ RCSID
 #include <sys/types.h>
 #include <afs/procmgmt.h>	/* signal(), kill(), wait(), etc. */
 #include <sys/stat.h>
-#ifdef AFS_NT40_ENV
 #include <fcntl.h>
+#ifdef AFS_NT40_ENV
 #include <io.h>
 #include <windows.h>
 #include <WINNT/afsevent.h>
@@ -88,7 +88,6 @@ RCSID
 #include "host.h"
 #ifdef AFS_PTHREAD_ENV
 #include "softsig.h"
-char *(*threadNameProgram) ();
 #endif
 #if defined(AFS_SGI_ENV)
 #include "sys/schedctl.h"
@@ -168,6 +167,7 @@ int SawPctSpare;
 int debuglevel = 0;
 int printBanner = 0;
 int rxJumbograms = 1;		/* default is to send and receive jumbograms. */
+int rxMaxMTU = -1;
 afs_int32 implicitAdminRights = PRSFS_LOOKUP;	/* The ADMINISTER right is 
 						 * already implied */
 afs_int32 readonlyServer = 0;
@@ -318,14 +318,9 @@ ResetCheckDescriptors(void)
 
 #if defined(AFS_PTHREAD_ENV)
 char *
-threadName(void)
+threadNum(void)
 {
-    char threadid[16];
-    if (LogLevel > 999) {
-	afs_snprintf(threadid, 16, "%d", pthread_getspecific(rx_thread_id_key));
-	return threadid;
-    } else 
-	return NULL;
+    return pthread_getspecific(rx_thread_id_key);
 }
 #endif
 
@@ -342,8 +337,10 @@ get_key(char *arock, register afs_int32 akvno, char *akey)
 	return 1;
     }
     code = afsconf_GetKey(confDir, akvno, tkey.key);
-    if (code)
+    if (code) {
+	ViceLog(0, ("afsconf_GetKey failure: kvno %d code %d\n", akvno, code));
 	return code;
+    }
     memcpy(akey, tkey.key, sizeof(tkey.key));
     return 0;
 
@@ -718,6 +715,7 @@ FlagMsg()
     /* default supports help flag */
 
     strcpy(buffer, "Usage: fileserver ");
+    strcpy(buffer, "[-auditlog <log path>] ");
     strcat(buffer, "[-d <debug level>] ");
     strcat(buffer, "[-p <number of processes>] ");
     strcat(buffer, "[-spare <number of spare blocks>] ");
@@ -739,6 +737,10 @@ FlagMsg()
     strcat(buffer, "[-rxpck <number of rx extra packets>] ");
     strcat(buffer, "[-rxdbg (enable rx debugging)] ");
     strcat(buffer, "[-rxdbge (enable rxevent debugging)] ");
+    strcat(buffer, "[-rxmaxmtu <bytes>] ");
+#if AFS_PTHREAD_ENV
+    strcat(buffer, "[-vattachpar <number of volume attach threads>] ");
+#endif
 #ifdef	AFS_AIX32_ENV
     strcat(buffer, "[-m <min percentage spare in partition>] ");
 #endif
@@ -751,6 +753,7 @@ FlagMsg()
     strcat(buffer, "[-realm <Kerberos realm name>] ");
     strcat(buffer, "[-udpsize <size of socket buffer in bytes>] ");
     strcat(buffer, "[-sendsize <size of send buffer in bytes>] ");
+    strcat(buffer, "[-abortthreshold <abort threshold>] ");
 /*   strcat(buffer, "[-enable_peer_stats] "); */
 /*   strcat(buffer, "[-enable_process_stats] "); */
     strcat(buffer, "[-help]\n");
@@ -934,6 +937,14 @@ ParseArgs(int argc, char *argv[])
 		return -1; 
 	    }
 	    rxpackets = atoi(argv[++i]);
+#ifdef AFS_PTHREAD_ENV
+	} else if (!strcmp(argv[i], "-vattachpar")) {
+            if ((i + 1) >= argc) {
+		fprintf(stderr, "missing argument for -vattachpar\n"); 
+		return -1; 
+	    }
+	    vol_attach_threads = atoi(argv[++i]);
+#endif /* AFS_PTHREAD_ENV */
 	} else if (!strcmp(argv[i], "-s")) {
 	    Sawsmall = 1;
             if ((i + 1) >= argc) {
@@ -1043,6 +1054,19 @@ ParseArgs(int argc, char *argv[])
 #endif
 	else if (!strcmp(argv[i], "-nojumbo")) {
 	    rxJumbograms = 0;
+	} else if (!strcmp(argv[i], "-rxmaxmtu")) {
+	    if ((i + 1) >= argc) {
+		fprintf(stderr, "missing argument for -rxmaxmtu\n"); 
+		return -1; 
+	    }
+	    rxMaxMTU = atoi(argv[++i]);
+	    if ((rxMaxMTU < RX_MIN_PACKET_SIZE) || 
+		(rxMaxMTU > RX_MAX_PACKET_DATA_SIZE)) {
+		printf("rxMaxMTU %d% invalid; must be between %d-%d\n",
+		       rxMaxMTU, RX_MIN_PACKET_SIZE, 
+		       RX_MAX_PACKET_DATA_SIZE);
+		return -1;
+	    }
 	} else if (!strcmp(argv[i], "-realm")) {
 	    extern char local_realm[AFS_REALM_SZ];
 	    if ((i + 1) >= argc) {
@@ -1085,6 +1109,36 @@ ParseArgs(int argc, char *argv[])
 	} else if (!strcmp(argv[i], "-enable_process_stats")) {
 	    rx_enableProcessRPCStats();
 	}
+	else if (strcmp(argv[i], "-auditlog") == 0) {
+	    int tempfd, flags;
+	    FILE *auditout;
+	    char oldName[MAXPATHLEN];
+	    char *fileName = argv[++i];
+	    
+#ifndef AFS_NT40_ENV
+	    struct stat statbuf;
+	    
+	    if ((lstat(fileName, &statbuf) == 0) 
+		&& (S_ISFIFO(statbuf.st_mode))) {
+		flags = O_WRONLY | O_NONBLOCK;
+	    } else 
+#endif
+	    {
+		strcpy(oldName, fileName);
+		strcat(oldName, ".old");
+		renamefile(fileName, oldName);
+		flags = O_WRONLY | O_TRUNC | O_CREAT;
+	    }
+	    tempfd = open(fileName, flags, 0666);
+	    if (tempfd > -1) {
+		auditout = fdopen(tempfd, "a");
+		if (auditout) {
+		    osi_audit_file(auditout);
+		} else
+		    printf("Warning: auditlog %s not writable, ignored.\n", fileName);
+	    } else
+		printf("Warning: auditlog %s not writable, ignored.\n", fileName);
+	}
 #ifndef AFS_NT40_ENV
 	else if (strcmp(argv[i], "-syslog") == 0) {
 	    /* set syslog logging flag */
@@ -1094,6 +1148,10 @@ ParseArgs(int argc, char *argv[])
 	    serverLogSyslogFacility = atoi(argv[i] + 8);
 	}
 #endif
+	else if (strcmp(argv[i], "-mrafslogs") == 0) {
+	    /* set syslog logging flag */
+	    mrafsStyleLogs = 1;
+	} 
 	else {
 	    return (-1);
 	}
@@ -1475,7 +1533,7 @@ Do_VLRegisterRPC()
     if (code) {
 	if (code == VL_MULTIPADDR) {
 	    ViceLog(0,
-		    ("VL_RegisterAddrs rpc failed; The ethernet address exist on a different server; repair it\n"));
+		    ("VL_RegisterAddrs rpc failed; The IP address exists on a different server; repair it\n"));
 	    ViceLog(0,
 		    ("VL_RegisterAddrs rpc failed; See VLLog for details\n"));
 	    return code;
@@ -1587,6 +1645,7 @@ main(int argc, char *argv[])
     sigaction(SIGABRT, &nsa, NULL);
     sigaction(SIGSEGV, &nsa, NULL);
 #endif
+    osi_audit_init();
 
     /* Initialize dirpaths */
     if (!(initAFSDirPath() & AFSDIR_SERVER_PATHS_OK)) {
@@ -1715,8 +1774,8 @@ main(int argc, char *argv[])
 	V_BreakVolumeCallbacks = BreakVolumeCallBacksLater;
     }
 
-#if defined(AFS_PTHREAD_ENV)
-    threadNameProgram = threadName;
+#ifdef AFS_PTHREAD_ENV
+    SetLogThreadNumProgram( threadNum );
 #endif
 
     /* initialize libacl routines */
@@ -1749,6 +1808,9 @@ main(int argc, char *argv[])
 	/* Don't send and don't allow 3.4 clients to send jumbograms. */
 	rx_SetNoJumbo();
     }
+    if (rxMaxMTU != -1) {
+	rx_SetMaxMTU(rxMaxMTU);
+    }
     rx_GetIFInfo();
     rx_SetRxDeadTime(30);
     sc[0] = rxnull_NewServerSecurityObject();
