@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/volser/volmain.c,v 1.18.2.1 2004/10/18 07:12:29 shadow Exp $");
+    ("$Header: /cvs/openafs/src/volser/volmain.c,v 1.18.2.4 2006/02/22 04:09:32 jaltman Exp $");
 
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -59,6 +59,8 @@ RCSID
 #include <afs/cellconfig.h>
 #include <afs/keys.h>
 #include <ubik.h>
+#include <fcntl.h>
+#include <sys/stat.h>
 
 #include "volser.h"
 #include <errno.h>
@@ -99,6 +101,13 @@ int Testing = 0;		/* for ListViceInodes */
 			  exit(code);                             \
 		       }
 
+#if defined(AFS_PTHREAD_ENV)
+char *
+threadNum(void)
+{
+    return pthread_getspecific(rx_thread_id_key);
+}
+#endif
 
 static afs_int32
 MyBeforeProc(struct rx_call *acall)
@@ -233,6 +242,7 @@ main(int argc, char **argv)
     char commandLine[150];
     int i;
     int rxJumbograms = 1;	/* default is to send and receive jumbograms. */
+    int rxMaxMTU = -1;
     int bufSize = 0;		/* temp variable to read in udp socket buf size */
 
 #ifdef	AFS_AIX32_ENV
@@ -250,6 +260,7 @@ main(int argc, char **argv)
     sigaction(SIGABRT, &nsa, NULL);
     sigaction(SIGSEGV, &nsa, NULL);
 #endif
+    osi_audit_init();
     osi_audit(VS_StartEvent, 0, AUD_END);
 
     /* Initialize dirpaths */
@@ -284,8 +295,51 @@ main(int argc, char **argv)
 		       lwps, MAXLWP);
 		lwps = MAXLWP;
 	    }
+	} else if (strcmp(argv[code], "-auditlog") == 0) {
+	    int tempfd, flags;
+	    FILE *auditout;
+	    char oldName[MAXPATHLEN];
+	    char *fileName = argv[++code];
+
+#ifndef AFS_NT40_ENV
+	    struct stat statbuf;
+	    
+	    if ((lstat(fileName, &statbuf) == 0) 
+		&& (S_ISFIFO(statbuf.st_mode))) {
+		flags = O_WRONLY | O_NONBLOCK;
+	    } else 
+#endif
+	    {
+		strcpy(oldName, fileName);
+		strcat(oldName, ".old");
+		renamefile(fileName, oldName);
+		flags = O_WRONLY | O_TRUNC | O_CREAT;
+	    }
+	    tempfd = open(fileName, flags, 0666);
+	    if (tempfd > -1) {
+		auditout = fdopen(tempfd, "a");
+		if (auditout) {
+		    osi_audit_file(auditout);
+		    osi_audit(VS_StartEvent, 0, AUD_END);
+		} else
+		    printf("Warning: auditlog %s not writable, ignored.\n", fileName);
+	    } else
+		printf("Warning: auditlog %s not writable, ignored.\n", fileName);
 	} else if (strcmp(argv[code], "-nojumbo") == 0) {
 	    rxJumbograms = 0;
+	} else if (!strcmp(argv[code], "-rxmaxmtu")) {
+	    if ((code + 1) >= argc) {
+		fprintf(stderr, "missing argument for -rxmaxmtu\n"); 
+		exit(1); 
+	    }
+	    rxMaxMTU = atoi(argv[++code]);
+	    if ((rxMaxMTU < RX_MIN_PACKET_SIZE) || 
+		(rxMaxMTU > RX_MAX_PACKET_DATA_SIZE)) {
+		printf("rxMaxMTU %d% invalid; must be between %d-%d\n",
+		       rxMaxMTU, RX_MIN_PACKET_SIZE, 
+		       RX_MAX_PACKET_DATA_SIZE);
+		exit(1);
+	    }
 	} else if (strcmp(argv[code], "-sleep") == 0) {
 	    sscanf(argv[++code], "%d/%d", &TTsleep, &TTrun);
 	    if ((TTsleep < 0) || (TTrun <= 0)) {
@@ -324,12 +378,16 @@ main(int argc, char **argv)
 	  usage:
 #ifndef AFS_NT40_ENV
 	    printf("Usage: volserver [-log] [-p <number of processes>] "
+		   "[-auditlog <log path>] "
+		   "[-nojumbo] [-rxmaxmtu <bytes>] "
 		   "[-udpsize <size of socket buffer in bytes>] "
 		   "[-syslog[=FACILITY]] "
 		   "[-enable_peer_stats] [-enable_process_stats] "
 		   "[-help]\n");
 #else
 	    printf("Usage: volserver [-log] [-p <number of processes>] "
+		   "[-auditlog <log path>] "
+		   "[-nojumbo] [-rxmaxmtu <bytes>] "
 		   "[-udpsize <size of socket buffer in bytes>] "
 		   "[-enable_peer_stats] [-enable_process_stats] "
 		   "[-help]\n");
@@ -346,6 +404,10 @@ main(int argc, char **argv)
 #endif
     InitErrTabs();
 
+#ifdef AFS_PTHREAD_ENV
+    SetLogThreadNumProgram( threadNum );
+#endif
+
 #ifdef AFS_NT40_ENV
     if (afs_winsockInit() < 0) {
 	ReportErrorEventAlt(AFSEVT_SVR_WINSOCK_INIT_FAILED, 0, argv[0], 0);
@@ -374,6 +436,9 @@ main(int argc, char **argv)
 	/* Don't allow 3.4 vos clients to send jumbograms and we don't send. */
 	rx_SetNoJumbo();
     }
+    if (rxMaxMTU != -1) {
+	rx_SetMaxMTU(rxMaxMTU);
+    }
     rx_GetIFInfo();
     rx_SetRxDeadTime(420);
     memset(busyFlags, 0, sizeof(busyFlags));
